#ifndef __INTERPOL_H__
#define __INTERPOL_H__

float inter4pol (short* buf, float index, long size);
/*float inter4pol_stereo (short* buf, float index, long size);*/
float inter4pol_float (float* buf, double index, long size);

#endif /* __INTERPOL_H__ */

